| 38 | |
| 39 | // Simple test kernel that increments a value using a single thread. |
| 40 | __global__ __launch_bounds__(ROCPRIM_DEFAULT_MAX_BLOCK_SIZE) void increment(int* data) |
| 41 | { |
| 42 | const int gid = blockIdx.x * blockDim.x + threadIdx.x; |
| 43 | if (!gid) |
| 44 | data[gid]++; |
| 45 | } |
| 46 | |
| 47 | // Another simple kernel that can be used to test atomics inside a graph. |
| 48 | __global__ __launch_bounds__(ROCPRIM_DEFAULT_MAX_BLOCK_SIZE) void atomicIncrement(int* data) |
nothing calls this directly
no outgoing calls
no test coverage detected